@@ -15,14 +15,22 @@ class CheckFix(_pyaud.plugins.Fix):
     Utilize the ``--check`` and ``--in-place`` flags.
     """
 
+    check = "--check"
+    in_place = "--in-place"
+
+    @property
+    def args(self) -> _t.Tuple[_t.Union[str, _Path], ...]:
+        """Default args to include with subclass."""
+        return ()
+
     def audit(self, *args: str, **kwargs: bool) -> int:
         return self.subprocess[self.exe[0]].call(
-            "--check", *_pyaud.files.args(), *args, **kwargs
+            self.check, *_pyaud.files.args(), *self.args, *args, **kwargs
         )
 
     def fix(self, *args: str, **kwargs: bool) -> int:
         return self.subprocess[self.exe[0]].call(
-            "--in-place", *_pyaud.files.args(), *args, **kwargs
+            self.in_place, *_pyaud.files.args(), *self.args, *args, **kwargs
         )
 
 
